[Haiku-commits] r31213 - in haiku/trunk/src/add-ons: accelerants/nvidia accelerants/nvidia/engine kernel/drivers/graphics/nvidia
rudolfc at mail.berlios.de
rudolfc at mail.berlios.de
Tue Jun 23 22:52:39 CEST 2009
Author: rudolfc
Date: 2009-06-23 22:52:30 +0200 (Tue, 23 Jun 2009)
New Revision: 31213
ViewCVS: http://svn.berlios.de/viewcvs/haiku?rev=31213&view=rev
Modified:
haiku/trunk/src/add-ons/accelerants/nvidia/ProposeDisplayMode.c
haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_general.c
haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_info.c
haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/README.html
haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html
haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/driver.c
haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/nvidia.settings
Log:
added DDC/EDID widescreen detection for analog connected screens. Switched off the force widescreen option so autodetection is actually used. This should fix non-ws DVI connected screens displaying black screens or shutting off on non-native modes. Bumped version to 0.93.
Modified: haiku/trunk/src/add-ons/accelerants/nvidia/ProposeDisplayMode.c
===================================================================
--- haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_general.c 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_general.c 2009-06-23 20:52:30 UTC (rev 31213)
@@ -1,7 +1,7 @@
/* Authors:
Mark Watson 12/1999,
Apsed,
- Rudolf Cornelissen 10/2002-5/2009
+ Rudolf Cornelissen 10/2002-6/2009
tst..
*/
@@ -92,7 +92,7 @@
{
status_t status;
- LOG(1,("POWERUP: Haiku nVidia Accelerant 0.92 running.\n"));
+ LOG(1,("POWERUP: Haiku nVidia Accelerant 0.93 running.\n"));
/* log VBLANK INT usability status */
if (si->ps.int_assigned)
Modified: haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_info.c
===================================================================
--- haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_info.c 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_info.c 2009-06-23 20:52:30 UTC (rev 31213)
@@ -2191,7 +2191,7 @@
/* select other CRTC for primary head use if specified by user in settings file */
if (si->ps.secondary_head && si->settings.switchhead)
{
- LOG(2,("INFO: inverting head use (specified in settings file)\n"));
+ LOG(2,("INFO: inverting head use (specified in nvidia.settings file)\n"));
si->ps.crtc2_prim = !si->ps.crtc2_prim;
}
}
@@ -2584,18 +2584,34 @@
if (!si->ps.con1_screen.digital) {
si->ps.monitors |= CRTC1_VGA;
si->ps.crtc1_aspect = si->ps.con1_screen.aspect;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
}
} else {
- if (nv_dac_crt_connected()) si->ps.monitors |= CRTC1_VGA;
+ if (nv_dac_crt_connected()) {
+ si->ps.monitors |= CRTC1_VGA;
+ /* assume 4:3 monitor */
+ si->ps.crtc1_aspect = 1.33;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
+ }
}
/* secondary connector */
if (si->ps.con2_screen.have_edid) {
if (!si->ps.con2_screen.digital) {
si->ps.monitors |= CRTC2_VGA;
si->ps.crtc2_aspect = si->ps.con2_screen.aspect;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc2_aspect = 1.60;
}
} else {
- if (nv_dac2_crt_connected()) si->ps.monitors |= CRTC2_VGA;
+ if (nv_dac2_crt_connected()) {
+ si->ps.monitors |= CRTC2_VGA;
+ /* assume 4:3 monitor */
+ si->ps.crtc2_aspect = 1.33;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc2_aspect = 1.60;
+ }
}
/* setup correct output and head use */
@@ -2713,9 +2729,20 @@
/* (load sensing is confirmed working OK on NV11.) */
/* primary connector: */
if (si->ps.con1_screen.have_edid) {
- if (!si->ps.con1_screen.digital) si->ps.monitors |= CRTC1_VGA;
+ if (!si->ps.con1_screen.digital) {
+ si->ps.monitors |= CRTC1_VGA;
+ si->ps.crtc1_aspect = si->ps.con1_screen.aspect;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
+ }
} else {
- if (nv_dac_crt_connected()) si->ps.monitors |= CRTC1_VGA;
+ if (nv_dac_crt_connected()) {
+ si->ps.monitors |= CRTC1_VGA;
+ /* assume 4:3 monitor */
+ si->ps.crtc1_aspect = 1.33;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
+ }
}
/* (sense analog monitor on secondary connector is impossible on NV11) */
@@ -2777,9 +2804,20 @@
/* (load sensing is confirmed working OK on all cards.) */
/* primary connector: */
if (si->ps.con1_screen.have_edid) {
- if (!si->ps.con1_screen.digital) si->ps.monitors |= CRTC1_VGA;
+ if (!si->ps.con1_screen.digital) {
+ si->ps.monitors |= CRTC1_VGA;
+ si->ps.crtc1_aspect = si->ps.con1_screen.aspect;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
+ }
} else {
- if (nv_dac_crt_connected()) si->ps.monitors |= CRTC1_VGA;
+ if (nv_dac_crt_connected()) {
+ si->ps.monitors |= CRTC1_VGA;
+ /* assume 4:3 monitor */
+ si->ps.crtc1_aspect = 1.33;
+ /* force widescreen type if requested */
+ if (si->settings.force_ws) si->ps.crtc1_aspect = 1.60;
+ }
}
//fixme? add TVout (only, so no CRT connected) support...
Modified: haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/README.html
===================================================================
--- haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/README.html 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/README.html 2009-06-23 20:52:30 UTC (rev 31213)
@@ -53,7 +53,7 @@
<li>If the driver still seems to create 'random' trouble make sure you have a fully functional VGA BIOS, or system BIOS for embedded cards (check for updates on the manufacturor's site). Make sure you mail me if you still have trouble but also if this version fixed that!
<li>If on a laptop the internal panel doesn't work when you connect an external monitor, make sure you set 'output device selection' to 'internal' (instead of 'auto') in the system BIOS if it has such an option. If you have this symptom on a normal card, or on a laptop without that BIOS option then you are probably out of luck for dualhead support;
<li><strong>NV40 architecture cards:</strong> (GeForce 6xxx, but 6800 AGP seems to be OK)<br>
- Secondary analog monitor detection doesn't work and we can't control very well to which connector the card's output gets routed (lack of specs). This means you might have to experiment a bit with the way you connect your monitor to the card. A single analog or DVI screen should work OK, and two analog screens should be OK as well.
+ Secondary analog monitor load detection doesn't work and we can't control very well to which connector the card's output gets routed (lack of specs). This means you might have to experiment a bit with the way you connect your monitor to the card. A single analog or DVI screen should work OK, and two analog screens should be OK as well.
</ul>
<br>
<hr>
@@ -229,11 +229,9 @@
<li><strong>force_ws:</strong><br>
This option (if enabled) overrules the aspect ratio detection for screens inside the driver. When set to <strong>true</strong> it forces all monitors to be treated as widescreen types.
<ul>
- <li><strong>false:</strong><br>
-If you select <strong>force_ws false</strong> the driver will autodetect the screen's aspect ratio if it can, otherwise it will force 4:3 aspect. Screens that are connected with a DVI cable and screens inside a laptop are autodetected (according to the cardBIOS presets done), but analog connected screens will always make the driver block widescreen modes. Connected analog TV sets are always treated like widescreen devices though.
- <li><strong>true:</strong> (default setting) <br> With this setting all monitors are treated as being widescreen types. This setting should only be used if you are having trouble using a widescreen monitor, because on non-widescreen monitors there's a (small) chance of destroying them if used with a widescreen mode. So use this setting with care.<br>
-<strong>Note please:</strong><br>
-The default setting was changed from <strong>false</strong> to being <strong>true</strong> on request by Haiku because widescreen monitors are rapidly becoming commonplace these days. In the future EDID will be implemented in the driver to actually fetch this info from the connected screens.
+ <li><strong>false:</strong> (default setting)<br>
+If you select <strong>force_ws false</strong> the driver will autodetect the screen's aspect ratio if it can, otherwise it will force 4:3 aspect. Screens that are connected with a DVI cable and screens inside a laptop are autodetected (according to the cardBIOS presets done), analog connected screens will also be autodetected if DDC/EDID works: otherwise the driver blocks widescreen modes. Connected analog TV sets are always treated like widescreen devices though.
+ <li><strong>true:</strong><br> With this setting all monitors are treated as being widescreen types. This setting should only be used if you are having trouble using a widescreen monitor, because on non-widescreen monitors there's a (small) chance of destroying them if used with a widescreen mode. Some non-widescreen monitors will simply shut-off or display a black screen. So use this setting with care.<br>
</ul>
<li><strong>primary:</strong> (set to disabled by default)<br>
Primary lets you force a certain card to be used as primary card in your system if you have multiple graphics cards installed: so it will display your desktop. To enable this (hack) feature uncomment this item and fill in the exact name of the card that is to be primary (as exported by the kerneldriver in /dev/graphics/). If you are going to select a card other than the one displaying your system's POST messages at bootup, make sure you also set 'usebios false' as otherwise the card(s) aren't coldstarted by the driver.<br>
@@ -255,6 +253,6 @@
<hr>
<br>
<a href="mailto:info.be-hold at inter.nl.net">Rudolf Cornelissen.</a>
-<p>(Page last updated on May 1, 2009)</p>
+<p>(Page last updated on June 23, 2009)</p>
</body>
</html>
Modified: haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html
===================================================================
--- haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/UPDATE.html 2009-06-23 20:52:30 UTC (rev 31213)
@@ -4,7 +4,7 @@
</head>
<body>
<p><h2>Changes done for each driverversion:</h2></p>
-<p><h1>head (SVN 0.91, Rudolf)</h1></p>
+<p><h1>head (SVN 0.93, Rudolf)</h1></p>
<ul>
<li>Fixed driver assuming enabling AGP mode succeeded on some occasions if it did not block it itself. Blocking AGP mode completely via the AGP busmanager (option 'block_agp') resulted in a crashing acceleration engine because it was setup for AGP transfers instead of using PCI transfers. Error was solved with help from user kraton.
<li>Fixed shared_info struct problem occuring when 3D 'accelerant' is used (tested Alpha 4.1): the TVencoder type definition list apparantly gets some memory assigned these days when done inside the definition of shared_info. Moved encoder list outside the shared_info definition.
@@ -12,16 +12,17 @@
<li>Modified two default settings for the driver:
<ul>
<li>'pgm_panel' is now preset to 'false' since this will probably increase chances of a good picture on panels outthere.
-<li>'force_ws' is now (re-enabled but) preset to 'true' since the number of widescreen monitors outthere is rapidly becoming mainstream.<br> <strong>Note please:</strong><br>
-'force_ws' was hardcoded to setting 'true' some time ago by the Haiku team because of these monitors.
+<li>'force_ws' is (re-enabled and) preset to 'false' since automatic widescreen detection now works for both analog and digital screens (thanks to added DDC/EDID processing).<br> <strong>Note please:</strong><br>
+'force_ws' was hardcoded to setting 'true' some time ago by the Haiku team because of lacking analog monitor widescreen autodetection.
</ul>
<li>Added 'block_acc' option in nvidia.settings to completely disable the acceleration engine. Use this as a work-around if the acceleration engine misbehaves.
<li>Fixed card/system hanging after trying to log LVDS/TMDS distinction info. This (at least) fixes one NV34 trying to startup after a failed kernel VESA modeswitch without using the driver's coldstart option. Might very well help on other type cards too.
<li>HDTV video upto/including 1920x1080p can now be played back using overlay on Geforce cards where overlay is supported. On TNT1/TNT2/TNT2-M64 this can't be done and bitmap output is used.
-<li>Added partial DDC/EDID support: dumping monitor specs to logfile only for now.
+<li>Added partial DDC/EDID support: dumping monitor specs to logfile, detecting analog connected screens and doing analog widescreen autodetection.
<li>Added confirmed support for laptop card with ID 0x01d7: Quadro NVS 110M/GeForce 7300 Go. Also fixed support for laptop card with ID 0x01d8: GeForce 7400 Go: the 'laptop' definition was missing here.
<li>Fixed acceleration engine crashes on at least G72 cards (Geforce 7300/7400/7500) by powering up new part(s) of the acceleration engines too..
<li>Modified GPU PTimer programming which according to the Nouveau project fixes LVDS panel programming in some cases.
+<li>Corrected/Added detection of third I2C bus on cards that support it. The old detection method for a third and (non-existing) fourth bus was faulty. The driver uses I2C channels for monitor DDC/EDID and TVencoder communications.
</ul>
<p><h1>nv_driver 0.80 (Rudolf)</h1></p>
<ul>
@@ -251,7 +252,7 @@
<p><h1>Still todo:</h1></p>
<ul>
<li>Extend TVout feature to support more encoder-types (Chrontel, Philips);
- <li>Improve/extend various stuff when/if possible (like adding DDC/EDID, GTF).
+ <li>Improve/extend various stuff when/if possible (like extending the use of DDC/EDID).
</ul>
</p>
</body>
Modified: haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/driver.c
===================================================================
--- haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/driver.c 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/driver.c 2009-06-23 20:52:30 UTC (rev 31213)
@@ -4,7 +4,7 @@
Other authors:
Mark Watson;
- Rudolf Cornelissen 3/2002-3/2009.
+ Rudolf Cornelissen 3/2002-6/2009.
*/
@@ -379,7 +379,7 @@
true, // dma_acc
false, // vga_on_tv
false, // force_sync
- true, // force_ws
+ false, // force_ws
false, // block_acc
0, // gpu_clk
0, // ram_clk
Modified: haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/nvidia.settings
===================================================================
--- haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/nvidia.settings 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/kernel/drivers/graphics/nvidia/nvidia.settings 2009-06-23 20:52:30 UTC (rev 31213)
@@ -1,4 +1,4 @@
-# Settings file for the nv driver and accelerant
+# Settings file for the nvidia driver and accelerant
#
# This file should be moved to the directory
# ~/config/settings/kernel/drivers/
@@ -21,7 +21,7 @@
dma_acc true # if true enable DMA cmd fetching for 2D acc (instead of using PIO)
#tv_output 0 # disabled or 0 = autodetect, 1 = Y/C (and CVBS if possible), 2 = CVBS
force_sync false # if true forces 3D rendering to be synchronized to the vertical retrace
-force_ws true # if true forces widescreen type detection for all connected screens
+force_ws false # if true forces widescreen type detection for all connected screens
block_acc false # if true disables the acceleration engine
# WARNING: tweak alert! modify stuff below on your own risk...
More information about the Haiku-commits
mailing list
--- haiku/trunk/src/add-ons/accelerants/nvidia/ProposeDisplayMode.c 2009-06-23 15:52:32 UTC (rev 31212)
+++ haiku/trunk/src/add-ons/accelerants/nvidia/ProposeDisplayMode.c 2009-06-23 20:52:30 UTC (rev 31213)
@@ -19,6 +19,7 @@
/* Standard VESA modes,
* plus panel specific resolution modes which are internally modified during run-time depending on the requirements of the actual
* panel connected. The modes as listed here, should timing-wise be as compatible with analog (CRT) monitors as can be... */
+//fixme: if EDID monitor found create list via common EDID code...
static const display_mode mode_list[] = {
/* 4:3 modes; 307.2k pixels */
{ { 25175, 640, 656, 752, 800, 480, 490, 492, 525, 0}, B_CMAP8, 640, 480, 0, 0, MODE_FLAGS}, /* Vesa_Monitor_ at 60Hz_(640X480X8.Z1) */
@@ -85,8 +86,10 @@
/* 16:10 panel mode; 2.304M pixels */
{ { 193160, 1920, 2048, 2256, 2592, 1200, 1201, 1204, 1242, T_POSITIVE_SYNC}, B_CMAP8, 1920, 1200, 0, 0, MODE_FLAGS}, /* Vesa_Monitor_ at 60Hz_(1920X1200) */
//{ { 160000, 1920, 2010, 2060, 2110, 1200, 1202, 1208, 1235, T_POSITIVE_SYNC}, B_CMAP8, 1920, 1200, 0, 0, MODE_FLAGS}, /* Vesa_Monitor_ at 60Hz_(1920X1200) */
-/* 16:9 panel mode; 1280x720 */
+/* 16:9 panel mode; 1280x720 (HDTV 1280x720p) */
{ { 74520, 1280, 1368, 1424, 1656, 720, 724, 730, 750, T_POSITIVE_SYNC}, B_CMAP8, 1280, 720, 0, 0, MODE_FLAGS}, /* Vesa_Monitor_ at 60Hz_(1280X720) */
+/* fixme, add: 16:9 panel mode; 1366x768 (HDTV '1280x720p') */
+/* fixme, add: 16:9 panel mode; 1920x1080 (HDTV 1920x1080p) */
};
@@ -140,86 +143,82 @@
/* disable aspect checks for a requested TVout mode when mode is TVout capable */
if (!si->ps.tvout
|| !(BT_check_tvmode(*target) && (target->flags & TV_BITS))) {
- /* check if all connected output devices can display the requested mode's aspect: */
+ /* check if all connected output devices can display the requested mode's aspect.
+ * assuming 16:10 screens can display non-WS modes, but cannot (correctly) display 16:9 modes;
+ * assuming 16:9 screens can display non-WS modes, and can display 16:10 modes. */
/* calculate display mode aspect */
target_aspect = (target->timing.h_display / ((float)target->timing.v_display));
/* NOTE:
* allow 0.10 difference so 5:4 aspect panels will be able to use 4:3 aspect modes! */
switch (si->ps.monitors) {
- case CRTC1_TMDS: /* digital panel on head 1, nothing on head 2 */
- if (si->ps.crtc1_aspect < (target_aspect - 0.10)) {
- LOG(4, ("PROPOSEMODE: connected panel1 is not widescreen type, aborted.\n"));
+ case 0: /* no monitor found at all */
+ /* if forcing widescreen type was requested don't block mode */
+ if (target_aspect > 1.34 && !si->settings.force_ws) {
+ LOG(4, ("PROPOSEMODE: not all output devices can display widescreen modes, aborted.\n"));
return B_ERROR;
}
break;
- case CRTC2_TMDS: /* nothing on head 1, digital panel on head 2 */
- if (si->ps.crtc2_aspect < (target_aspect - 0.10)) {
- LOG(4, ("PROPOSEMODE: connected panel2 is not widescreen type, aborted.\n"));
+ case CRTC1_TMDS: /* digital panel on head 1, nothing on head 2 */
+ case CRTC1_VGA: /* analog connected screen on head 1, nothing on head 2 */
+ if (si->ps.crtc1_aspect < (target_aspect - 0.10)) {
+ LOG(4, ("PROPOSEMODE: screen at crtc1 is not widescreen type, aborted.\n"));
return B_ERROR;
}
break;
- case CRTC1_TMDS | CRTC2_TMDS: /* digital panels on both heads */
- if ((si->ps.crtc1_aspect < (target_aspect - 0.10))
- || (si->ps.crtc2_aspect < (target_aspect - 0.10))) {
- LOG(4, ("PROPOSEMODE: not all connected panels are widescreen type, aborted.\n"));
+ case CRTC2_TMDS: /* nothing on head 1, digital panel on head 2 */
+ case CRTC2_VGA: /* analog connected screen on head 2, nothing on head 1 */
+ if (si->ps.crtc2_aspect < (target_aspect - 0.10)) {
+ LOG(4, ("PROPOSEMODE: screen at crtc2 is not widescreen type, aborted.\n"));
return B_ERROR;
}
break;
-//
-// case CRTC1_VGA: /* analog connected screen on head 1, nothing on head 2 */
-// if (si->ps.panel1_aspect < (target_aspect - 0.10)) {
-// LOG(4, ("PROPOSEMODE: connected panel1 is not widescreen type, aborted.\n"));
-// return B_ERROR;
-// }
-// break;
-//
- default:
- /* at least one analog monitor is connected, or nothing detected at all */
- /* (if forcing widescreen type was requested don't block mode) */
- if (target_aspect > 1.34 && !si->settings.force_ws) {
- LOG(4, ("PROPOSEMODE: not all output devices can display widescreen modes, aborted.\n"));
+ case CRTC1_TMDS | CRTC2_TMDS: /* digital panels on both heads */
+ case CRTC1_VGA | CRTC2_VGA: /* analog connected screens on both heads */
+ case CRTC1_TMDS | CRTC2_VGA: /* digital panel on head 1, analog connected screen on head 2 */
+ case CRTC1_VGA | CRTC2_TMDS: /* analog connected screen on head 1, digital panel on head 2 */
+ default: /* more than two screens connected (illegal setup) */
+ if ((si->ps.crtc1_aspect < (target_aspect - 0.10)) ||
+ (si->ps.crtc2_aspect < (target_aspect - 0.10))) {
+ LOG(4, ("PROPOSEMODE: not all connected screens are widescreen type, aborted.\n"));
return B_ERROR;
}
break;
}
-
- /* only export widescreen panel-TV modes when an exact resolution match exists,
- * to prevent the modelist from becoming too crowded */
- if (target_aspect > 1.61 && !si->settings.force_ws) {
- status_t panel_TV_stat = B_ERROR;
-
- if (si->ps.monitors & CRTC1_TMDS) {
- if (target->timing.h_display == si->ps.p1_timing.h_display
- && target->timing.v_display == si->ps.p1_timing.v_display)
- panel_TV_stat = B_OK;
- }
- if (si->ps.monitors & CRTC2_TMDS) {
- if (target->timing.h_display == si->ps.p2_timing.h_display
- && target->timing.v_display == si->ps.p2_timing.v_display)
- panel_TV_stat = B_OK;
- }
- if (panel_TV_stat != B_OK) {
- LOG(4, ("PROPOSEMODE: WS panel_TV mode requested but no such TV here, aborted.\n"));
- return B_ERROR;
- }
- }
}
/* check if panel(s) can display the requested resolution (if connected) */
if (si->ps.monitors & CRTC1_TMDS) {
if (target->timing.h_display > si->ps.p1_timing.h_display
|| target->timing.v_display > si->ps.p1_timing.v_display) {
- LOG(4, ("PROPOSEMODE: panel1 can't display requested resolution, aborted.\n"));
+ LOG(4, ("PROPOSEMODE: panel at crtc11 can't display requested resolution, aborted.\n"));
return B_ERROR;
}
}
if (si->ps.monitors & CRTC2_TMDS) {
if (target->timing.h_display > si->ps.p2_timing.h_display
|| target->timing.v_display > si->ps.p2_timing.v_display) {
- LOG(4, ("PROPOSEMODE: panel2 can't display requested resolution, aborted.\n"));
+ LOG(4, ("PROPOSEMODE: panel at crtc2 can't display requested resolution, aborted.\n"));
return B_ERROR;
}
}
+//still expand/update concerning edid, among others.. (setup accounting for cross-connected vga screens...):
+/*
+ if (si->ps.monitors & CRTC1_VGA) {
+ if (target->timing.h_display > si->ps.xxx_timing.h_display
+ || target->timing.v_display > si->ps.xxx_timing.v_display) {
+ LOG(4, ("PROPOSEMODE: analog screen at crtc1 can't display requested resolution, aborted.\n"));
+ return B_ERROR;
+ }
+ }
+ if (si->ps.monitors & CRTC2_VGA) {
+ if (target->timing.h_display > si->ps.yyy_timing.h_display
+ || target->timing.v_display > si->ps.yyy_timing.v_display) {
+ LOG(4, ("PROPOSEMODE: analog screen at crtc2 can't display requested resolution, aborted.\n"));
+ return B_ERROR;
+ }
+ }
+*/
+//end still update.
/* validate display vs. virtual */
if (target->timing.h_display > target->virtual_width || want_same_width)
Modified: haiku/trunk/src/add-ons/accelerants/nvidia/engine/nv_general.c
@@ -140,86 +143,82 @@
}
- /* check if panel(s) can display the requested resolution (if connected) */
+ /* check if screen(s) can display the requested resolution (if connected) */
if (si->ps.monitors & CRTC1_TMDS) {
if (target->timing.h_display > si->ps.p1_timing.h_display
===================================================================